// 47jMarbles.js
// 
// Demonstrates how to set up a JitterListener object to listen
// to the output of a Jitter object instantiated within [js].
//
// rld, 7.05
//

// create a [jit.window] object for our display 
// (this is the object we'll "listen" to):
var mywindow = new JitterObject("jit.window","callback");
// turn off depth testing... we're using blending instead:
mywindow.depthbuffer = 0; 
// turn ON idlemousing... we want to listen for it:
mywindow.idlemouse = 1; 

// create a [jit.gl.render] object for drawing into our window:
var myrender = new JitterObject("jit.gl.render","callback");
// use a 2-dimensional projection:
myrender.ortho = 2; 
// set background to black with full erase opacity (no trails):
myrender.erase_color = [0,0,0,1]; 

// create a [jit.gl.gridshape] object for use to control with the mouse
var mywidget = new JitterObject("jit.gl.gridshape","callback");
mywidget.shape = "circle";
mywidget.lighting_enable = 1;
mywidget.smooth_shading = 1;
mywidget.scale = [0.1,0.1,0.1];
mywidget.color = [1,1,1,0.5] ;
mywidget.blend_enable = 1;
mywidget.position = [0,0]; // no z necessary in orthographic projection

var circle = new Array();

// create a JitterListener for our [jit.window] object
var mylistener = new JitterListener(mywindow.getregisteredname(), thecallback);

var index = 0;


function thecallback(event) 
// callback function to handle events triggered by mousing 
// in our [jit.window]
{
	var x,y,button; // some local variables

	if (event.eventname=="mouse") { 
	// we're entering, dragging within, or leaving a "mouse click" event

		// arguments are (x,y,button,cmd,shift,capslock,option,ctrl)... 
		// we only care about the first three
		x = event.args[0];
		y = event.args[1];
		button = event.args[2];
		if (button) // we're clicked down
		{
			//mywidget.color = [0,1,0,1]; // color our control object green
			//mywidget.shape = "circle"; // change it to a donut shape
			circle[index] = new node();
			circle[index].position = [x, y];
			
			index++;
		}
		else // we've just unclicked
		{
			mywidget.color = [1,0,0,1]; // color our object red
			mywidget.shape = "circle"; // change back to a sphere
		}
	}
	else if (event.eventname=="mouseidle") { 
	// we're mousing over the window with the mouse up
		x = event.args[0];
		y = event.args[1];
		mywidget.color = [1,1,1,1] ; // color our object white
	}
	else if (event.eventname=="mouseidleout") { 
	// we're no longer mousing over the window
		x = event.args[0];
		y = event.args[1];
		mywidget.color = [1,1,1,0.5] ; // make our object translucent
	}

	// move our control object to the drawing context's 
	// equivalent of where our mouse event occurred:
	mywidget.position = myrender.screentoworld(x,y); 
}
// don't allow this function to be called from Max
thecallback.local = 1; 

function bang() 
// main drawing loop... figure out which little spheres to move 
// and drive the renderer
{

	
	// rendering block...
	myrender.erase(); // erase the drawing context
	myrender.drawclients(); // draw the client objects
	myrender.swap(); // swap in the new drawing
}

function fullscreen(v) 
// function to send the [jit.window] into fullscreen mode
{
	mywindow.fullscreen = v;
}

function floating(v) 
{
	mywindow.floating = v;
}

function node(x, y, index)
{												//add a new object where we've just clicked
	this.prototype = new JitterObject("jit.gl.gridshape","callback");
	this.prototype.shape = "circle";
	this.prototype.lighting_enable = 1;
	this.prototype.smooth_shading = 1;
	this.prototype.scale = [.1, .1 ,.1];
	this.prototype.color = [0, 0, 1, 1] ;
	this.prototype.position = [x, y];		//place a circle at the current mouse position
	this.prototype.blend_enable = 1;
	
	this.prototype.draw = drawNode;
}

function drawNode()
{
    node.draw();
	}